@@ -61,6 +61,7 @@ private Q_SLOTS:
     void genericBody_data();
     void genericBody();
     void nullGenericBody();
+    void markdownBody();
     void subtitle();
     void nullSubtitle();
     void mediaInfo();
@@ -346,6 +347,13 @@ void EventHandlerTest::nullGenericBody()
     QCOMPARE(noEventHandler.getGenericBody(), QString());
 }
 
+void EventHandlerTest::markdownBody()
+{
+    eventHandler.setEvent(room->messageEvents().at(0).get());
+
+    QCOMPARE(eventHandler.getMarkdownBody(), QStringLiteral("This is an example\ntext message"));
+}
+
 void EventHandlerTest::subtitle()
 {
     auto event = room->messageEvents().at(0).get();
