@@ -2,6 +2,7 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "messageeventmodel.h"
+#include "linkpreviewer.h"
 #include "messageeventmodel_logging.h"
 
 #include "neochatconfig.h"
@@ -20,7 +21,9 @@
 
 #include "enums/delegatetype.h"
 #include "eventhandler.h"
+#include "events/pollevent.h"
 #include "models/reactionmodel.h"
+#include "texthandler.h"
 
 using namespace Quotient;
 
@@ -34,7 +37,6 @@ QHash<int, QByteArray> MessageEventModel::roleNames() const
     roles[TimeStringRole] = "timeString";
     roles[SectionRole] = "section";
     roles[AuthorRole] = "author";
-    roles[ContentRole] = "content";
     roles[HighlightRole] = "isHighlighted";
     roles[SpecialMarksRole] = "marks";
     roles[ProgressInfoRole] = "progressInfo";
@@ -65,12 +67,19 @@ QHash<int, QByteArray> MessageEventModel::roleNames() const
     roles[LatitudeRole] = "latitude";
     roles[LongitudeRole] = "longitude";
     roles[AssetRole] = "asset";
+    roles[PollHandlerRole] = "pollHandler";
     return roles;
 }
 
 MessageEventModel::MessageEventModel(QObject *parent)
     : QAbstractListModel(parent)
 {
+    connect(this, &MessageEventModel::modelAboutToBeReset, this, [this]() {
+        resetting = true;
+    });
+    connect(this, &MessageEventModel::modelReset, this, [this]() {
+        resetting = false;
+    });
 }
 
 NeoChatRoom *MessageEventModel::room() const
@@ -101,6 +110,9 @@ void MessageEventModel::setRoom(NeoChatRoom *room)
             if (const auto &roomMessageEvent = &*event->viewAs<RoomMessageEvent>()) {
                 createEventObjects(roomMessageEvent);
             }
+            if (event->event()->is<PollStartEvent>()) {
+                m_currentRoom->createPollHandler(eventCast<const PollStartEvent>(event->event()));
+            }
         }
 
         if (m_currentRoom->timelineSize() < 10 && !room->allHistoryLoaded()) {
@@ -151,6 +163,9 @@ void MessageEventModel::setRoom(NeoChatRoom *room)
                         }
                     }
                 }
+                if (event->is<PollStartEvent>()) {
+                    m_currentRoom->createPollHandler(eventCast<const PollStartEvent>(event.get()));
+                }
             }
             m_initialized = true;
             beginInsertRows({}, timelineBaseIndex(), timelineBaseIndex() + int(events.size()) - 1);
@@ -160,6 +175,9 @@ void MessageEventModel::setRoom(NeoChatRoom *room)
                 if (const auto &roomMessageEvent = dynamic_cast<RoomMessageEvent *>(event.get())) {
                     createEventObjects(roomMessageEvent);
                 }
+                if (event->is<PollStartEvent>()) {
+                    m_currentRoom->createPollHandler(eventCast<const PollStartEvent>(event.get()));
+                }
             }
             if (rowCount() > 0) {
                 rowBelowInserted = rowCount() - 1; // See #312
@@ -221,6 +239,10 @@ void MessageEventModel::setRoom(NeoChatRoom *room)
         });
         connect(m_currentRoom, &Room::replacedEvent, this, [this](const RoomEvent *newEvent) {
             refreshLastUserEvents(refreshEvent(newEvent->id()) - timelineBaseIndex());
+            const RoomMessageEvent *message = eventCast<const RoomMessageEvent>(newEvent);
+            if (message != nullptr) {
+                createEventObjects(message);
+            }
         });
         connect(m_currentRoom, &Room::updatedEvent, this, [this](const QString &eventId) {
             if (eventId.isEmpty()) { // How did we get here?
@@ -231,8 +253,11 @@ void MessageEventModel::setRoom(NeoChatRoom *room)
                 if (const auto &event = dynamic_cast<const RoomMessageEvent *>(&**eventIt)) {
                     createEventObjects(event);
                 }
+                if (eventIt->event()->is<PollStartEvent>()) {
+                    m_currentRoom->createPollHandler(eventCast<const PollStartEvent>(eventIt->event()));
+                }
             }
-            refreshEventRoles(eventId, {ReactionRole, ShowReactionsRole, Qt::DisplayRole});
+            refreshEventRoles(eventId, {Qt::DisplayRole});
         });
         connect(m_currentRoom, &Room::changed, this, [this]() {
             for (auto it = m_currentRoom->messageEvents().rbegin(); it != m_currentRoom->messageEvents().rend(); ++it) {
@@ -253,6 +278,12 @@ void MessageEventModel::setRoom(NeoChatRoom *room)
         lastReadEventId.clear();
     }
     endResetModel();
+
+    // After reset put a read marker in if required.
+    // This is needed when changing back to a room that has already loaded messages.
+    if (room) {
+        moveReadMarker(m_currentRoom->lastFullyReadEventId());
+    }
 }
 
 int MessageEventModel::refreshEvent(const QString &eventId)
@@ -479,28 +510,6 @@ QVariant MessageEventModel::data(const QModelIndex &idx, int role) const
         return eventHandler.getAuthor(isPending);
     }
 
-    if (role == ContentRole) {
-        if (evt.isRedacted()) {
-            auto reason = evt.redactedBecause()->reason();
-            return (reason.isEmpty()) ? i18n("[REDACTED]") : i18n("[REDACTED: %1]").arg(evt.redactedBecause()->reason());
-        }
-
-        if (auto e = eventCast<const RoomMessageEvent>(&evt)) {
-            if (e->msgtype() == Quotient::MessageEventType::Location) {
-                return e->contentJson();
-            }
-            // Cannot use e.contentJson() here because some
-            // EventContent classes inject values into the copy of the
-            // content JSON stored in EventContent::Base
-            return e->hasFileContent() ? QVariant::fromValue(e->content()->originalJson) : QVariant();
-        };
-
-        if (auto e = eventCast<const StickerEvent>(&evt)) {
-            return QVariant::fromValue(e->image().originalJson);
-        }
-        return evt.contentJson();
-    }
-
     if (role == HighlightRole) {
         return eventHandler.isHighlighted();
     }
@@ -696,6 +705,10 @@ QVariant MessageEventModel::data(const QModelIndex &idx, int role) const
         return row < static_cast<int>(m_currentRoom->pendingEvents().size());
     }
 
+    if (role == PollHandlerRole) {
+        return QVariant::fromValue<PollHandler *>(m_currentRoom->poll(evt.id()));
+    }
+
     return {};
 }
 
@@ -713,19 +726,37 @@ void MessageEventModel::createEventObjects(const Quotient::RoomMessageEvent *eve
 {
     auto eventId = event->id();
 
-    EventHandler eventHandler;
-    eventHandler.setRoom(m_currentRoom);
-    eventHandler.setEvent(event);
-
-    if (auto linkPreviewer = eventHandler.getLinkPreviewer()) {
-        m_linkPreviewers[eventId] = linkPreviewer;
+    if (m_linkPreviewers.contains(eventId)) {
+        if (!LinkPreviewer::hasPreviewableLinks(event)) {
+            m_linkPreviewers.remove(eventId);
+        }
     } else {
-        m_linkPreviewers.remove(eventId);
+        if (LinkPreviewer::hasPreviewableLinks(event)) {
+            m_linkPreviewers[eventId] = QSharedPointer<LinkPreviewer>(new LinkPreviewer(m_currentRoom, event));
+        }
     }
-    if (auto reactionModel = eventHandler.getReactions()) {
-        m_reactionModels[eventId] = reactionModel;
+
+    // ReactionModel handles updates to add and remove reactions, we only need to
+    // handle adding and removing whole models here.
+    if (m_reactionModels.contains(eventId)) {
+        // If a model already exists but now has no reactions remove it
+        if (m_reactionModels[eventId]->rowCount() <= 0) {
+            m_reactionModels.remove(eventId);
+            if (!resetting) {
+                refreshEventRoles(eventId, {ReactionRole, ShowReactionsRole});
+            }
+        }
     } else {
-        m_reactionModels.remove(eventId);
+        if (m_currentRoom->relatedEvents(*event, Quotient::EventRelation::AnnotationType).count() > 0) {
+            // If a model doesn't exist and there are reactions add it.
+            auto reactionModel = QSharedPointer<ReactionModel>(new ReactionModel(event, m_currentRoom));
+            if (reactionModel->rowCount() > 0) {
+                m_reactionModels[eventId] = reactionModel;
+                if (!resetting) {
+                    refreshEventRoles(eventId, {ReactionRole, ShowReactionsRole});
+                }
+            }
+        }
     }
 }
 
