@@ -3,8 +3,6 @@
 
 #include "serverlistmodel.h"
 
-#include "controller.h"
-
 #include <Quotient/connection.h>
 
 #include <QDebug>
@@ -13,6 +11,8 @@
 #include <KConfigGroup>
 #include <KSharedConfig>
 
+#include "neochatconnection.h"
+
 ServerListModel::ServerListModel(QObject *parent)
     : QAbstractListModel(parent)
 {
